==> poedit_1.3.4.orig.tar.gz: poedit-1.3.4/src/icons.h <==
/*
 *  This file is part of poEdit (http://www.poedit.org)
 *
 *  Copyright (C) 2004-2005 Vaclav Slavik
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a
 *  copy of this software and associated documentation files (the "Software"),
 *  to deal in the Software without restriction, including without limitation
 *  the rights to use, copy, modify, merge, publish, distribute, sublicense,
 *  and/or sell copies of the Software, and to permit persons to whom the
 *  Software is furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in
 *  all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 *  DEALINGS IN THE SOFTWARE.
 *
 *  $Id: icons.h,v 1.4 2005/06/19 16:43:21 vaclavslavik Exp $
 *
 *  Art provider classes
 *
 */

#ifndef _ICONS_H_
#define _ICONS_H_

#include <wx/artprov.h>

#ifdef wxCHECK_VERSION_FULL
    #if defined(__WXGTK20__) && wxCHECK_VERSION_FULL(2,5,2,8)
        #define HAS_THEMES_SUPPORT
    #endif
#endif

class wxPoeditStdArtProvider : public wxArtProvider
{
protected:
    virtual wxBitmap CreateBitmap(const wxArtID& id,
                                  const wxArtClient& client,
                                  const wxSize& size);
};


#ifdef HAS_THEMES_SUPPORT
class wxPoeditThemeArtProvider : public wxArtProvider
{
protected:
    virtual wxBitmap CreateBitmap(const wxArtID& id,
                                  const wxArtClient& client,
                                  const wxSize& size);
};
#endif

#endif // _ICONS_H_

==> poedit_1.3.5.orig.tar.gz: poedit-1.3.5/src/icons.h <==
/*
 *  This file is part of poEdit (http://www.poedit.org)
 *
 *  Copyright (C) 2004-2006 Vaclav Slavik
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a
 *  copy of this software and associated documentation files (the "Software"),
 *  to deal in the Software without restriction, including without limitation
 *  the rights to use, copy, modify, merge, publish, distribute, sublicense,
 *  and/or sell copies of the Software, and to permit persons to whom the
 *  Software is furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in
 *  all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 *  DEALINGS IN THE SOFTWARE.
 *
 *  $Id: icons.h 1022 2006-08-31 21:57:29Z vaclavslavik $
 *
 *  Art provider classes
 *
 */

#ifndef _ICONS_H_
#define _ICONS_H_

#include <wx/artprov.h>

#if defined(__WXGTK20__)
    #define HAS_THEMES_SUPPORT
#endif

// see icons.cpp for explanation
#if wxCHECK_VERSION(2,7,1)
    #define HAS_INSERT_PROVIDER
#endif

class PoeditArtProvider : public wxArtProvider
{
protected:
    virtual wxBitmap CreateBitmap(const wxArtID& id,
                                  const wxArtClient& client,
                                  const wxSize& size);
};

#endif // _ICONS_H_
